@@ -177,7 +177,8 @@ define([
                           "data_select"
                         ],
                         "output": true,
-                        "required": true
+                        "required": true,
+                        "value": 'vp_df'
                       }
                     ]
                   }
@@ -235,9 +236,14 @@ define([
                     type = 'open';
                 }
 
+                let extensionList = [];
+                if (that.state.fileExtension !== '') {
+                    extensionList = [ that.state.fileExtension ];
+                }
+
                 let fileNavi = new FileNavigation({
                     type: type,
-                    extensions: [ that.state.fileExtension ],
+                    extensions: extensionList,
                     finish: function(filesPath, status, error) {
                         let {file, path} = filesPath[0];
                         that.state.selectedFile = file;
@@ -309,10 +315,11 @@ define([
             /** Implement generating template */
             let page = $(fileHtml);
 
-            let allocateSelector = new DataSelector({
-                pageThis: this, id: 'vp_sampleReturn', placeholder: 'Variable name'
-            });
-            $(page).find('#vp_sampleReturn').replaceWith(allocateSelector.toTagString());
+            // Removed dataselector for Allocation input
+            // let allocateSelector = new DataSelector({
+            //     pageThis: this, id: 'vp_sampleReturn', placeholder: 'Variable name', value: 'vp_df'
+            // });
+            // $(page).find('#vp_sampleReturn').replaceWith(allocateSelector.toTagString());
 
             return page;
         }
