@@ -35,6 +35,7 @@ define([
             this.config.dataview = false;
             this.config.sizeLevel = 2;
             this.config.checkModules = ['plt'];
+            this.config.docs = 'https://matplotlib.org/stable/';
             
             this.setDefaultVariables();
             this.state = {
@@ -1308,8 +1309,8 @@ define([
                 'numerical': [
                     { label: 'count', method: 'count()' },
                     { label: 'unique count', method: 'unique()' },
-                    { label: 'sum', method: 'sum()' },
-                    { label: 'average', method: 'mean()' },
+                    { label: 'sum', method: 'sum(numeric_only=True)' },
+                    { label: 'average', method: 'mean(numeric_only=True)' },
                     { label: 'min', method: 'min()' },
                     { label: 'max', method: 'max()' }
                 ]
